@@ -102,7 +102,8 @@ KDE_NO_EXPORT FFServerSetting & FFServerSetting::operator = (const QStringList &
     width = *it++;
     height = *it++;
     acl.clear ();
-    for (; it != sl.end (); ++it)
+    QStringList::const_iterator end( sl.end() );
+    for (; it != end; ++it)
         acl.push_back (*it);
     return *this;
 }
@@ -145,7 +146,8 @@ KDE_NO_EXPORT const QStringList FFServerSetting::list () {
     sl.push_back (width);
     sl.push_back (height);
     QStringList::const_iterator it = acl.begin ();
-    for (; it != acl.end (); ++it)
+    QStringList::const_iterator end( acl.end () );
+    for (; it != end; ++it)
         sl.push_back (*it);
     return sl;
 }
@@ -300,7 +302,8 @@ KDE_NO_EXPORT void KMPlayerPrefBroadcastFormatPage::setSettings (const FFServerS
     accesslist->setNumRows (0);
     accesslist->setNumRows (50);
     QStringList::const_iterator it = fs.acl.begin ();
-    for (int i = 0; it != fs.acl.end (); ++i, ++it)
+    QStringList::const_iterator end( fs.acl.end () );
+    for (int i = 0; it != end; ++i, ++it)
         accesslist->setItem (i, 0, new QTableItem (accesslist, QTableItem::Always, *it));
 }
 
@@ -401,7 +404,7 @@ static bool stopProcess (KProcess * process, const char * cmd = 0L) {
 }
 
 
-KDE_NO_CDTOR_EXPORT KMPlayerBroadcastConfig::KMPlayerBroadcastConfig (KMPlayer * player, KMPlayerFFServerConfig * fsc)
+KDE_NO_CDTOR_EXPORT KMPlayerBroadcastConfig::KMPlayerBroadcastConfig (KMPlayer::PartBase * player, KMPlayerFFServerConfig * fsc)
  : m_player (player),
    m_ffserverconfig (fsc),
    m_ffmpeg_process (0L),
@@ -425,13 +428,14 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::write (KConfig * config) {
 }
 
 KDE_NO_EXPORT void KMPlayerBroadcastConfig::read (KConfig * config) {
-    std::for_each (ffserversettingprofiles.begin (), ffserversettingprofiles.end (), Deleter<FFServerSetting>);
+    std::for_each (ffserversettingprofiles.begin (), ffserversettingprofiles.end (), KMPlayer::Deleter<FFServerSetting>());
     ffserversettingprofiles.clear ();
     config->setGroup (strBroadcast);
     ffserversettings = config->readListEntry (strFFServerCustomSetting, ';');
     QStringList profiles = config->readListEntry (strFFServerProfiles, ';');
     QStringList::iterator pr_it = profiles.begin ();
-    for (; pr_it != profiles.end (); ++pr_it) {
+    QStringList::iterator pr_end( profiles.end () );
+    for (; pr_it != pr_end; ++pr_it) {
         QStringList sl = config->readListEntry (QString ("Profile_") + *pr_it, ';');
         if (sl.size () > 10) {
             FFServerSetting * ffs = new FFServerSetting (sl);
@@ -460,10 +464,9 @@ QFrame * KMPlayerBroadcastConfig::prefPage (QWidget * parent) {
     if (!m_configpage) {
         m_configpage = new KMPlayerPrefBroadcastFormatPage (parent, ffserversettingprofiles);
         connect (m_configpage->startbutton, SIGNAL (clicked ()), this, SLOT (startServer ()));
-        connect (m_player, SIGNAL (sourceChanged (KMPlayerSource *)),
-                 this, SLOT (sourceChanged (KMPlayerSource *)));
+        connect (m_player, SIGNAL (sourceChanged (KMPlayer::Source *, KMPlayer::Source *)), this, SLOT (sourceChanged (KMPlayer::Source *,KMPlayer::Source *)));
         m_configpage->startbutton->setEnabled
-            (!m_player->process ()->source ()->videoDevice ().isEmpty ());
+            (!m_player->source ()->videoDevice ().isEmpty ());
     }
     return m_configpage;
 }
@@ -492,12 +495,13 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startServer () {
     connect (m_ffserver_process, SIGNAL (processExited (KProcess *)),
              this, SLOT (processStopped (KProcess *)));
     QString conffile = locateLocal ("data", "kmplayer/ffserver.conf");
-    const char * noaudio = m_player->process ()->source ()->audioDevice ().isEmpty () ? "NoAudio" : "";
+    const char * noaudio = m_player->source ()->audioDevice ().isEmpty () ? "NoAudio" : "";
     FFServerSetting ffs;
     m_configpage->getSettings (ffs);
     QString acl;
     QStringList::iterator it = ffs.acl.begin ();
-    for (; it != ffs.acl.end (); ++it)
+    QStringList::iterator end(  ffs.acl.end () );
+    for (; it != end; ++it)
         acl += QString ("ACL allow ") + *it + QString ("\n");
     unlink (m_ffserverconfig->feedfile.ascii ());
     QFile qfile (conffile);
@@ -553,13 +557,11 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startFeed () {
     if (m_ffmpeg_process)
         m_ffmpeg_process->stop ();
     delete m_ffmpeg_process;
-    m_ffmpeg_process = new FFMpeg (m_player);
-    m_ffmpeg_process->setSource (m_player->process ()->source ());
-    connect (m_ffmpeg_process, SIGNAL (finished ()),
-             this, SLOT (feedFinished ()));
+    m_ffmpeg_process = new KMPlayer::FFMpeg (m_player, m_player->settings ());
+    connect (m_ffmpeg_process, SIGNAL (stateChange (KMPlayer::Process::State, KMPlayer::Process::State)), this, SLOT (stateChange (KMPlayer::Process::State, KMPlayer::Process::State)));
     ffurl.sprintf ("http://localhost:%d/kmplayer.ffm", m_ffserverconfig->ffserverport);
     m_ffmpeg_process->setURL (KURL(ffurl));
-    if (!m_ffmpeg_process->play ()) {
+    if (!m_ffmpeg_process->play (m_player->source (), KMPlayer::NodePtr())) {
         KMessageBox::error (m_configpage, i18n ("Failed to start ffmpeg."), i18n ("Error"));
         stopProcess (m_ffserver_process);
         goto bail_out;
@@ -575,18 +577,20 @@ bail_out:
     m_configpage->setCursor (QCursor (Qt::ArrowCursor));
 }
 
-KDE_NO_EXPORT void KMPlayerBroadcastConfig::feedFinished () {
-    if (m_configpage)
-        m_configpage->feedled->setState (KLed::Off);
-    m_ffmpeg_process->deleteLater ();
-    m_ffmpeg_process = 0L;
-    kdDebug () << "ffmpeg process stopped " << m_endserver << endl;
-    if (m_endserver && !stopProcess (m_ffserver_process)) {
-        disconnect (m_ffserver_process,
-                SIGNAL (receivedStderr (KProcess *, char *, int)),
-                this, SLOT (processOutput (KProcess *, char *, int)));
-        KMessageBox::error (m_configpage, i18n ("Failed to end ffserver process."), i18n ("Error"));
-        processStopped (0L);
+KDE_NO_EXPORT void KMPlayerBroadcastConfig::stateChange (KMPlayer::Process::State old, KMPlayer::Process::State state) {
+    if (state < KMPlayer::Process::Buffering && old >KMPlayer::Process::Ready) {
+        if (m_configpage)
+            m_configpage->feedled->setState (KLed::Off);
+        m_ffmpeg_process->deleteLater ();
+        m_ffmpeg_process = 0L;
+        kdDebug () << "ffmpeg process stopped " << m_endserver << endl;
+        if (m_endserver && !stopProcess (m_ffserver_process)) {
+            disconnect (m_ffserver_process,
+                    SIGNAL (receivedStderr (KProcess *, char *, int)),
+                    this, SLOT (processOutput (KProcess *, char *, int)));
+            KMessageBox::error (m_configpage, i18n ("Failed to end ffserver process."), i18n ("Error"));
+            processStopped (0L);
+        }
     }
 }
 
@@ -596,14 +600,14 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::processStopped (KProcess *) {
         m_configpage->serverled->setState (KLed::Off);
         m_configpage->startbutton->setText (i18n ("Start"));
         m_configpage->startbutton->setEnabled
-            (!m_player->process ()->source ()->videoDevice ().isEmpty ());
+            (!m_player->source ()->videoDevice ().isEmpty ());
     }
     m_ffserver_process->deleteLater ();
     m_ffserver_process = 0L;
     emit broadcastStopped ();
 }
 
-KDE_NO_EXPORT void KMPlayerBroadcastConfig::sourceChanged (KMPlayerSource * source) {
+KDE_NO_EXPORT void KMPlayerBroadcastConfig::sourceChanged (KMPlayer::Source *, KMPlayer::Source * source) {
     if (m_configpage)
         m_configpage->startbutton->setEnabled (broadcasting () || (source && !source->videoDevice ().isEmpty ()));
 }
